@@ -1,14 +1,17 @@
 # -*- coding:utf-8 -*-
 # /usr/bin/env python
 """
-Date: 2020/2/27 16:39
+Date: 2021/12/9 19:09
 Desc:
 """
 import requests
 import pandas as pd
 
 
-url = "http://127.0.0.1:8000/stock_em_account"
-r = requests.get(url)
+url = "http://127.0.0.1:8080/spot_hist_sge"
+params = {
+    'query': 'symbol="Au99.99"'
+}
+r = requests.get(url, params=params)
 temp_df = pd.DataFrame.from_dict(r.json())
 print(temp_df)
